<template>
  <aside
      :class="`absolute transition-all rounded-xl overflow-hidden duration-200  bottom-0 ${show ? 'left-0 opacity-100 visible' : 'opacity-0 invisible -left-[100%]'} h-full w-full bg-white`"
  style="z-index: 1000">
    <div class="relative block overflow-hidden h-full">
      <div class="relative flex p-3 justify-center items-center h-12">
        <button @click="onClose"
                class="flex absolute left-3 m-y-auto btn btn-circle btn-ghost p-1 hover:bg-transparent  btn-sm">
          <svg width="20" height="20" viewBox="0 0 20 20" fill="none" xmlns="http://www.w3.org/2000/svg">
            <path
                d="M10 19.3307L0.666687 9.9974L10 0.664062L11.6625 2.2974L5.12919 8.83073H19.3334V11.1641H5.12919L11.6625 17.6974L10 19.3307Z"
                fill="#7646FC"/>
          </svg>
        </button>
        <div class="flex items-center gap-3 relative ">
          <span class="font-semibold text-xl">{{ heading }}</span>
        </div>
      </div>

      <div class=" relative block w-full h-full p-3 overflow-hidden" style="height: calc(100% - 8rem)">
        <perfect-scrollbar>
          <slot />
        </perfect-scrollbar>
      </div>
      <div v-if="enableAction" class="absolute bottom-0 left-0 block w-full p-3">
        <button @click="onSubmit"
                class="btn btn-primary flex items-center w-full hover:bg-scheme-primary hover:bg-opacity-90 text-white ">
          <span v-if="!loading && !isLoading">{{buttonText}}</span>
          <svg v-else class="animate-spin -ml-1 mr-3 h-5 w-5 text-white" xmlns="http://www.w3.org/2000/svg" fill="none"
               viewBox="0 0 24 24">
            <circle class="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle>
            <path class="opacity-75" fill="currentColor"
                  d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
          </svg>
        </button>
      </div>
    </div>
  </aside>
</template>

<script setup lang="ts">

import {ref} from "vue";

const loading = ref(false)

interface Props {
  show?: boolean,
  isLoading?: boolean,
  buttonText?: string,
  heading?: string,
  enableAction?: boolean,
  disableButton?: boolean,
}

let props = withDefaults(defineProps<Props>(), {
  show: false,
  isLoading: false,
  disableButton: false,
  buttonText: null,
  heading: "Heading",
  enableAction: false,
})

const emit = defineEmits(['onSubmit', 'onClear', 'onClose'])

const onSubmit = (e) => {
  emit("onSubmit", e)
}
const onClose = (e) => {
  emit("onClose", e)
}
</script>